@@ -12,7 +12,7 @@ Apache2::REST::Handler::bin - Proof of concept for binary output.
 
 =head2 GET
 
-Ouputs the logo png image
+Ouputs a small gif
 
 =cut
 
@@ -20,18 +20,15 @@ sub GET{
     my ( $self , $req , $resp ) = @_ ;
     
     $req->requestedFormat('bin') ;
-    $resp->binMimeType('image/png') ;
-    
-    my $exFile = __FILE__ ;
-    $exFile =~ s/bin\.pm$/bin_logo.png/ ;
-    open ( INFILE , '<'.$exFile ) or die "Cannot open $exFile\n" ;
-    my $bin = '' ;
-    {
-        local $/ = undef ;
-        $bin = <INFILE>;
-    }
-    close INFILE ;
+    $resp->binMimeType('image/gif') ;
     
+    my $bin = "GIF89a" ;
+    $bin .= pack("CC",01,00);
+    $bin .= pack("CCCCCCCC",1,0,128,0,0,255,255,255);
+    $bin .= pack("CCCCCCCC",0,0,0,33,249,4,1,0);
+    $bin .= pack("CCCCCCCC",0,0,0,44,0,0,0,0);
+    $bin .= pack("CCCCCCCC",1,0,1,0,0,2,2,68);
+    $bin .= pack("CCC",1,0,59);
     $resp->bin($bin) ;
     
     return Apache2::Const::HTTP_OK ;    
